@@ -10,14 +10,17 @@ require Locale::Utils::PlaceholderBabelFish;
 
 # code to format numeric values
 my $modifier_code = sub {
-    my ($value, $attribute) = @_; # $function_name not used
+    my ($value, $attributes) = @_; # $function_name not used
 
-    if ( $attribute eq 'numf' ) {
+    if ( $attributes =~ m{ \b numf \b }xms ) {
         # set the , between 3 digits
         while ( $value =~ s{(\d+) (\d{3})}{$1,$2}xms ) {}
         # German number format
         $value =~ tr{.,}{,.};
     }
+    $value = Locale::Utils::PlaceholderBabelFish
+        ->default_modifier_code
+        ->($value, $attributes);
 
     return $value;
 };
@@ -41,7 +44,7 @@ $obj->is_strict(1);
     ),
     "\n";
 
-for (undef, 0 .. 2, '3234567.890', 4_234_567.890) { ## no critic (MagicNumbers)
+for ( undef, 0 .. 2, '3234567.890', 4_234_567.890 ) { ## no critic (MagicNumbers)
     () = print
         $obj->expand_babel_fish(
             'foo #{count} bar ((#{count} singular|#{count} plural)) baz',
@@ -53,7 +56,7 @@ for (undef, 0 .. 2, '3234567.890', 4_234_567.890) { ## no critic (MagicNumbers)
 # formatted numeric
 $obj->modifier_code($modifier_code);
 
-for (undef, 0 .. 2, '3234567.890', 4_234_567.890) { ## no critic (MagicNumbers)
+for ( undef, 0 .. 2, '3234567.890', 4_234_567.890 ) { ## no critic (MagicNumbers)
     () = print
         $obj->expand_babel_fish(
             # same placeholder for _1 and _2
@@ -63,6 +66,16 @@ for (undef, 0 .. 2, '3234567.890', 4_234_567.890) { ## no critic (MagicNumbers)
         "\n";
 }
 
+# use numf and html from default modifier code
+() = print
+    $obj->expand_babel_fish(
+        # same placeholder for _1 and _2
+        'foo <strong>#{count :numf :html}</strong> bar #{text :html} baz',
+        count => 1234.56,
+        text  => '<text>',
+    ),
+    "\n";
+
 # $Id: 01_expand_babel_fish.pl 626 2015-10-05 17:09:23Z steffenw $
 
 __END__
@@ -83,3 +96,4 @@ foo 1 bar 1 singular baz
 foo 2 bar 2 plural baz
 foo 3.234.567,890 bar 3.234.567,890 plural baz
 foo 4.234.567,89 bar 4.234.567,89 plural baz
+foo <strong>1.234,56</strong> bar &lt;text&gt; baz
