@@ -3,6 +3,7 @@ package Locale::Utils::PlaceholderBabelFish; ## no critic (TidyCode)
 use strict;
 use warnings;
 use Carp qw(confess);
+use HTML::Entities qw(encode_entities);
 use List::Util qw(min);
 use Moo;
 use MooX::StrictConstructor;
@@ -10,17 +11,31 @@ use MooX::Types::MooseLike::Base qw(Bool CodeRef);
 use Scalar::Util qw(looks_like_number);
 use namespace::autoclean;
 
-our $VERSION = '0.002';
+our $VERSION = '0.003';
 
 has is_strict => (
     is  => 'rw',
     isa => Bool,
 );
 
+sub default_modifier_code {
+    return sub {
+        my ( $value, $attributes ) = @_;
+
+        if ( $attributes =~ m{ \b html \b }xms ) {
+            $value = encode_entities( $value, q{<>&"} );
+        }
+
+        return $value;
+    }
+};
+
 has modifier_code => (
     is      => 'rw',
     isa     => CodeRef,
     clearer => 'clear_modifier_code',
+    lazy    => 1,
+    default => \&default_modifier_code,
 );
 
 has plural_code => (
@@ -156,13 +171,13 @@ __END__
 
 Locale::Utils::PlaceholderBabelFish - Utils to expand BabelFish palaceholders
 
-$Id: PlaceholderBabelFish.pm 625 2015-10-05 16:38:04Z steffenw $
+$Id: PlaceholderBabelFish.pm 629 2015-10-31 17:36:02Z steffenw $
 
 $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils-PlaceholderBabelFish/trunk/lib/Locale/Utils/PlaceholderBabelFish.pm $
 
 =head1 VERSION
 
-0.002
+0.003
 
 =head1 SYNOPSIS
 
@@ -175,10 +190,10 @@ $HeadURL: svn+ssh://steffenw@svn.code.sf.net/p/perl-gettext-oo/code/Locale-Utils
         modifier_code => sub {
             my ( $value, $attribute ) = @_;
             return
-                $attribute eq '%.3f'
-                ? sprintf($attribute, $value)
-                : $attribute eq 'accusative'
-                ? accusative($value)
+                $attribute =~ m{ \b numf \b }xms
+                ? format_number($value)
+                : $attribute =~ m{ \b html \b }xms
+                ? encode_entiaccusative($value)
                 : $value;
         },
         # optional plural code
@@ -210,6 +225,20 @@ If is_strict is true: no replacement.
 
     $obj->is_strict(1); # boolean true or false;
 
+=head2 method default_modifier_code
+
+Implements the html attribute.
+For plain text messages in HTML the whole message will be escaped.
+In case of HTML messages the placeholder data have to escaped.
+
+    # class method
+    my $modifier_code = Locale::Utils::PlaceholderBabelFish->default_modifier_code;
+    # object method
+    my $modifier_code = $obj->default_modifier_code;
+
+    # call example
+    $value = $modifier_code->($value, $attributes);
+
 =head2 method modifier_code, clear_modifier_code
 
 The modifier code handles named attributes
@@ -220,11 +249,11 @@ and bar the attribute name.
 Space in front of the attribute name is allowed, e.g. C<#{foo :bar}>.
 
     my $code_ref = sub {
-        my ( $value, $attribute ) = @_;
+        my ( $value, $attributes ) = @_;
         return
-            $attribute eq 'num.03'
-            ? sprintf('%.03f, $value)
-            : $attribute eq 'accusative'
+            $attributes =~ m{ \b numf \b }
+            ? $value =~ tr{.}{,}
+            : $attribute =~ m{ \b accusative \b }xms
             ? accusative($value)
             : $value;
     };
